Arguments
formula
a symbolic representation of the model to be
estimated, in the form y ~, x1 + x2, where y is the
dependent variable and x1 and x2 are the explanatory
variables, and y, x1, and <
model
the name of a statistical model.
Type help.zelig("models") to see a list of currently supported
models
data
the name of a data frame containing the variables
referenced in the formula, or a list of multiply imputed data frames
each having the same variable names and row numbers (created by
mi)
...
additional arguments passed to zelig,
depending on the model to be estimated
by
a factor variable contained in data. Zelig will subset
the data frame based on the levels in the by variable, and
estimate a model for each subset. This a particularly powerful option
which will allow you to save a considerable
cite
If is set to "TRUE" (default), the model citation will be